@@ -9,10 +9,16 @@
 #define _NGINX_H_INCLUDED_
 
 
-#define nginx_version      1002009
-#define NGINX_VERSION      "1.2.9.7"
+#define nginx_version      1008001
+#define NGINX_VERSION      "1.8.1.8"
 #define NGINX_VER          "nginx-perl/" NGINX_VERSION
 
+#ifdef NGX_BUILD
+#define NGINX_VER_BUILD    NGINX_VER " (" NGX_BUILD ")"
+#else
+#define NGINX_VER_BUILD    NGINX_VER
+#endif
+
 #define NGINX_VAR          "NGINX"
 #define NGX_OLDPID_EXT     ".oldbin"
 
